@@ -1,3 +1,3 @@
 from sancty.run import start_terminal
-from sancty.render import Renderer
+from sancty.render import Renderer, ExternalError
 from sancty.read import Reader
